@@ -511,6 +511,7 @@ class ConnectionVcard:
                             'not-allowed'):
             app.log('avatar').info('vCard not available: %s %s',
                                    frm_jid, stanza_error)
+            callback(jid, resource, room, {})
             return
 
         vcard_node = stanza.getTag('vCard', namespace=nbxmpp.NS_VCARD)
@@ -850,10 +851,9 @@ class ConnectionHandlersBase:
                 obj.contact.contact_name = obj.contact_nickname
                 obj.need_redraw = True
 
-            if obj.old_show == obj.new_show and obj.contact.status == \
-            obj.status and obj.contact.priority == obj.prio and \
-            obj.contact.idle_time == obj.idle_time: # no change
-                return True
+            elif obj.old_show != obj.new_show or obj.contact.status != \
+            obj.status:
+                obj.need_redraw = True
         else:
             obj.contact = app.contacts.get_first_contact_from_jid(account,
                 jid)
@@ -1066,9 +1066,17 @@ class ConnectionHandlersBase:
                 conn=self, msg_obj=obj, stanza_id=obj.unique_id))
             return True
 
+    def _check_for_mam_compliance(self, room_jid, stanza_id):
+        namespace = muc_caps_cache.get_mam_namespace(room_jid)
+        if stanza_id is None and namespace == nbxmpp.NS_MAM_2:
+            helpers.add_to_mam_blacklist(room_jid)
+
     def _nec_gc_message_received(self, obj):
         if obj.conn.name != self.name:
             return
+
+        self._check_for_mam_compliance(obj.jid, obj.unique_id)
+
         if (app.config.should_log(obj.conn.name, obj.jid) and
                 obj.msgtxt and obj.nick):
             # if not obj.nick, it means message comes from room itself
